"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const diff = require("jest-diff");
const os_1 = require("os");
const api_1 = require("../utils/api");
const common_1 = require("./common");
const expectedProps = ['url', 'method'];
exports.toReturnResponse = async function (props, expected) {
    common_1.verifyProps(Object.assign({}, props), expectedProps);
    const { url, method, params, data, headers } = props;
    try {
        const printMethod = this.utils.printExpected(method);
        const printUrl = this.utils.printExpected(url);
        const notHint = this.utils.matcherHint('.not.toReturnResponse') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toReturnResponse') + os_1.EOL + os_1.EOL;
        const received = await api_1.getResponse(url, method, params, data, headers);
        const pass = this.equals(expected, received);
        const printReceived = this.utils.printReceived(received);
        const printExpected = this.utils.printExpected(expected);
        if (pass) {
            return {
                message: () => `${notHint}Expected response ${printReceived} not to equal ${printExpected}.${os_1.EOL}` +
                    `Request data: ${printMethod}: ${printUrl}`,
                pass: true,
            };
        }
        else {
            const diffString = diff(expected, received, {
                expand: true,
            });
            return {
                message: () => `${hint}Expected response ${printReceived} to equal ${printExpected}${os_1.EOL}` +
                    `Difference:${diffString ? `${os_1.EOL}${os_1.EOL}${diffString}` : ''}${os_1.EOL}` +
                    `Request data: ${printMethod}: ${printUrl}`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while getting response: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=api.js.map