"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const cloudwatch_1 = require("../utils/cloudwatch");
const common_1 = require("./common");
const expectedProps = ['region', 'function', 'pattern'];
exports.toHaveLog = async function (props, pattern) {
    common_1.verifyProps(Object.assign({}, props, { pattern }), expectedProps);
    const { region, function: functionName } = props;
    try {
        const printFunctionName = this.utils.printExpected(functionName);
        const printRegion = this.utils.printExpected(region);
        const printPattern = this.utils.printExpected(pattern) + os_1.EOL;
        const notHint = this.utils.matcherHint('.not.toHaveLog') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveLog') + os_1.EOL + os_1.EOL;
        const { events } = await cloudwatch_1.filterLogEvents(region, functionName, pattern);
        const found = events.length > 0;
        if (found) {
            // matching log found
            return {
                message: () => `${notHint}Expected ${printFunctionName} at region ${printRegion} not to have log matching pattern ${printPattern}`,
                pass: true,
            };
        }
        else {
            // matching log not found
            return {
                message: () => `${hint}Expected ${printFunctionName} at region ${printRegion} to have log matching pattern ${printPattern}`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while matching log: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=cloudwatch.js.map