"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sleep = async (ms) => {
    return await new Promise(resolve => setTimeout(resolve, ms));
};
exports.wrapWithRetries = (matcher) => {
    async function wrapped(props, ...args) {
        const { timeout = 2500, pollEvery = 500 } = props;
        const start = Date.now();
        let result = await matcher.apply(this, [props, ...args]);
        while (Date.now() - start < timeout) {
            // expecting pass === false
            if (this.isNot && !result.pass) {
                return result;
            }
            // expecting pass === true
            if (!this.isNot && result.pass) {
                return result;
            }
            // retry
            await module.exports.sleep(pollEvery);
            result = await matcher.apply(this, [props, ...args]);
        }
        return result;
    }
    return wrapped;
};
exports.verifyProps = (props, expectedProps) => {
    for (const prop of expectedProps) {
        const value = props[prop];
        if (!value) {
            throw new Error(`Missing ${prop} from received props`);
        }
    }
};
//# sourceMappingURL=common.js.map