"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const diff = require("jest-diff");
const os_1 = require("os");
const dynamoDb_1 = require("../utils/dynamoDb");
const common_1 = require("./common");
const expectedProps = ['region', 'table', 'key'];
exports.toHaveItem = async function (props, key, expected, strict = true) {
    common_1.verifyProps(Object.assign({}, props, { key }), expectedProps);
    const { region, table } = props;
    try {
        const printTable = this.utils.printExpected(table);
        const printRegion = this.utils.printExpected(region);
        const printKey = this.utils.printExpected(key) + os_1.EOL;
        const notHint = this.utils.matcherHint('.not.toHaveItem') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveItem') + os_1.EOL + os_1.EOL;
        let received = await dynamoDb_1.getItem(region, table, key);
        // check if item was found
        if (received) {
            // no expected item to compare with
            if (!expected) {
                return {
                    message: () => `${notHint}Expected ${printTable} at region ${printRegion} not to have item with key ${printKey}`,
                    pass: true,
                };
            }
            else {
                if (!strict) {
                    // remove keys that are in actual, but not in expected
                    Object.keys(received).forEach(actualKey => {
                        if (!expected.hasOwnProperty(actualKey)) {
                            /* istanbul ignore next */
                            const _a = received, _b = actualKey, omit = _a[_b], rest = __rest(_a, [typeof _b === "symbol" ? _b : _b + ""]);
                            received = rest;
                        }
                    });
                }
                // we check equality as well
                const pass = this.equals(expected, received);
                const printReceived = this.utils.printReceived(received);
                const printExpected = this.utils.printExpected(expected);
                if (pass) {
                    return {
                        message: () => `${notHint}Expected item ${printReceived} not to equal ${printExpected}`,
                        pass: true,
                    };
                }
                else {
                    const diffString = diff(expected, received, {
                        expand: true,
                    });
                    return {
                        message: () => `${hint}Expected item ${printReceived} to equal ${printExpected}${os_1.EOL}` +
                            `Difference:${diffString ? `${os_1.EOL}${os_1.EOL}${diffString}` : ''}`,
                        pass: false,
                    };
                }
            }
        }
        else {
            // no item was found
            return {
                message: () => `${hint}Expected ${printTable} at region ${printRegion} to have item with key ${printKey}`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while looking for item: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=dynamoDb.js.map