"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const kinesis_1 = require("../utils/kinesis");
const common_1 = require("./common");
const expectedProps = ['region', 'stream', 'matcher'];
exports.toHaveRecord = async function (props, matcher) {
    common_1.verifyProps(Object.assign({}, props, { matcher }), expectedProps);
    const { region, stream, timeout = 10 * 1000, pollEvery = 500 } = props;
    try {
        const printStream = this.utils.printExpected(stream);
        const printRegion = this.utils.printExpected(region);
        const notHint = this.utils.matcherHint('.not.toHaveRecord') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveRecord') + os_1.EOL + os_1.EOL;
        const found = await kinesis_1.existsInStream(region, stream, matcher, timeout, pollEvery);
        // check if record was found
        if (found) {
            return {
                message: () => `${notHint}Expected ${printStream} at region ${printRegion} not to have record`,
                pass: true,
            };
        }
        else {
            // no record was found
            return {
                message: () => `${hint}Expected ${printStream} at region ${printRegion} to have record`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while looking for record: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=kinesis.js.map