"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const diff = require("jest-diff");
const os_1 = require("os");
const s3_1 = require("../utils/s3");
const common_1 = require("./common");
const expectedProps = ['region', 'bucket', 'key'];
exports.toHaveObject = async function (props, key, expected) {
    common_1.verifyProps(Object.assign({}, props, { key }), expectedProps);
    const { region, bucket } = props;
    try {
        const printBucket = this.utils.printExpected(bucket);
        const printRegion = this.utils.printExpected(region);
        const printKey = this.utils.printExpected(key) + os_1.EOL;
        const notHint = this.utils.matcherHint('.not.toHaveObject') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveObject') + os_1.EOL + os_1.EOL;
        const { body: received, found } = await s3_1.getObject(region, bucket, key);
        // check if object was found
        if (found) {
            // no expected buffer to compare with
            if (!expected) {
                return {
                    message: () => `${notHint}Expected ${printBucket} at region ${printRegion} not to have object with key ${printKey}`,
                    pass: true,
                };
            }
            else {
                // we check equality as well
                const pass = this.equals(expected, received);
                const printReceived = this.utils.printReceived(received);
                const printExpected = this.utils.printExpected(expected);
                if (pass) {
                    return {
                        message: () => `${notHint}Expected object ${printReceived} not to equal ${printExpected}`,
                        pass: true,
                    };
                }
                else {
                    const diffString = diff(expected, received, {
                        expand: true,
                    });
                    return {
                        message: () => `${hint}Expected object ${printReceived} to equal ${printExpected}${os_1.EOL}` +
                            `Difference:${diffString ? `${os_1.EOL}${os_1.EOL}${diffString}` : ''}`,
                        pass: false,
                    };
                }
            }
        }
        else {
            // no item was found
            return {
                message: () => `${hint}Expected ${printBucket} at region ${printRegion} to have object with key ${printKey}`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while looking for object: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=s3.js.map