"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const sqs_1 = require("../utils/sqs");
const common_1 = require("./common");
const expectedProps = ['region', 'queueUrl', 'matcher'];
exports.toHaveMessage = async function (props, matcher) {
    common_1.verifyProps(Object.assign({}, props, { matcher }), expectedProps);
    const { region, queueUrl } = props;
    try {
        const printQueueUrl = this.utils.printExpected(queueUrl);
        const printRegion = this.utils.printExpected(region);
        const notHint = this.utils.matcherHint('.not.toHaveMessage') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveMessage') + os_1.EOL + os_1.EOL;
        const found = await sqs_1.existsInQueue(region, queueUrl, matcher);
        // check if record was found
        if (found) {
            return {
                message: () => `${notHint}Expected ${printQueueUrl} at region ${printRegion} not to have message`,
                pass: true,
            };
        }
        else {
            // no record was found
            return {
                message: () => `${hint}Expected ${printQueueUrl} at region ${printRegion} to have message`,
                pass: false,
            };
        }
    }
    catch (e) {
        // unknown error
        console.error(`Unknown error while looking for message: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=sqs.js.map