"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const diff = require("jest-diff");
const os_1 = require("os");
const stepFunctions_1 = require("../utils/stepFunctions");
const common_1 = require("./common");
const expectedProps = ['region', 'stateMachineArn', 'state'];
exports.toBeAtState = async function (props, expected) {
    common_1.verifyProps(Object.assign({}, props, { state: expected }), expectedProps);
    const { region, stateMachineArn } = props;
    try {
        const printStateMachineArn = this.utils.printExpected(stateMachineArn);
        const printRegion = this.utils.printExpected(region);
        const printExpected = this.utils.printExpected(expected) + os_1.EOL;
        const notHint = this.utils.matcherHint('.not.toBeAtState') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toBeAtState') + os_1.EOL + os_1.EOL;
        const received = await stepFunctions_1.getCurrentState(region, stateMachineArn);
        const pass = this.equals(expected, received);
        if (pass) {
            return {
                message: () => `${notHint}Expected ${printStateMachineArn} at region ${printRegion} not to be at state ${printExpected}`,
                pass: true,
            };
        }
        else {
            const diffString = diff(expected, received, {
                expand: true,
            });
            return {
                message: () => `${hint}Expected ${printStateMachineArn} at region ${printRegion} to be at state ${printExpected}` +
                    `Difference:${diffString ? `${os_1.EOL}${os_1.EOL}${diffString}` : ''}`,
                pass: false,
            };
        }
    }
    catch (e) {
        console.error(`Unknown error getting state machine state: ${e.message}`);
        throw e;
    }
};
exports.toHaveState = async function (props, expected) {
    common_1.verifyProps(Object.assign({}, props, { state: expected }), expectedProps);
    const { region, stateMachineArn } = props;
    try {
        const printStateMachineArn = this.utils.printExpected(stateMachineArn);
        const printRegion = this.utils.printExpected(region);
        const printExpected = this.utils.printExpected(expected) + os_1.EOL;
        const notHint = this.utils.matcherHint('.not.toHaveState') + os_1.EOL + os_1.EOL;
        const hint = this.utils.matcherHint('.toHaveState') + os_1.EOL + os_1.EOL;
        const states = await stepFunctions_1.getStates(region, stateMachineArn);
        const pass = states.includes(expected);
        if (pass) {
            return {
                message: () => `${notHint}Expected ${printStateMachineArn} at region ${printRegion} not to have state ${printExpected}`,
                pass: true,
            };
        }
        else {
            return {
                message: () => `${hint}Expected ${printStateMachineArn} at region ${printRegion} to have state ${printExpected}` +
                    `Found states: ${JSON.stringify(states)}`,
                pass: false,
            };
        }
    }
    catch (e) {
        console.error(`Unknown error getting state machine states: ${e.message}`);
        throw e;
    }
};
//# sourceMappingURL=stepFunctions.js.map