"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const getLogGroupName = (functionName) => `/aws/lambda/${functionName}`;
exports.filterLogEvents = async (region, functionName, pattern) => {
    const cloudWatchLogs = new AWS.CloudWatchLogs({ region });
    const logGroupName = getLogGroupName(functionName);
    const filterPattern = `"${pattern}"`; // enclose with "" to support special characters
    const { events = [] } = await cloudWatchLogs
        .filterLogEvents({
        filterPattern,
        interleaved: true,
        limit: 1,
        logGroupName,
    })
        .promise();
    return { events };
};
const getLogStreams = async (region, functionName) => {
    const cloudWatchLogs = new AWS.CloudWatchLogs({ region });
    const logGroupName = getLogGroupName(functionName);
    const { logStreams = [] } = await cloudWatchLogs
        .describeLogStreams({
        descending: true,
        logGroupName,
        orderBy: 'LastEventTime',
    })
        .promise();
    return { logStreams };
};
exports.deleteAllLogs = async (region, functionName) => {
    const { logStreams } = await getLogStreams(region, functionName);
    if (logStreams.length <= 0) {
        return;
    }
    const cloudWatchLogs = new AWS.CloudWatchLogs({ region });
    const logGroupName = getLogGroupName(functionName);
    const logStreamNames = logStreams.map(s => s.logStreamName || '');
    await Promise.all(logStreamNames.map(logStreamName => {
        return cloudWatchLogs
            .deleteLogStream({ logGroupName, logStreamName })
            .promise();
    }));
};
//# sourceMappingURL=cloudwatch.js.map