"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const itemToKey = (item, keySchema) => {
    let itemKey = {};
    keySchema.map(key => {
        itemKey = Object.assign({}, itemKey, { [key.AttributeName]: item[key.AttributeName] });
    });
    return itemKey;
};
exports.clearAllItems = async (region, tableName) => {
    // get the table keys
    const table = new AWS.DynamoDB({ region });
    const { Table = {} } = await table
        .describeTable({ TableName: tableName })
        .promise();
    const keySchema = Table.KeySchema || [];
    // get the items to delete
    const db = new AWS.DynamoDB.DocumentClient({ region });
    const scanResult = await db
        .scan({
        AttributesToGet: keySchema.map(key => key.AttributeName),
        TableName: tableName,
    })
        .promise();
    const items = scanResult.Items || [];
    if (items.length > 0) {
        const deleteRequests = items.map(item => ({
            DeleteRequest: { Key: itemToKey(item, keySchema) },
        }));
        await db
            .batchWrite({ RequestItems: { [tableName]: deleteRequests } })
            .promise();
    }
};
exports.writeItems = async (region, tableName, items) => {
    const db = new AWS.DynamoDB.DocumentClient({ region });
    const writeRequests = items.map(item => ({
        PutRequest: { Item: item },
    }));
    await db
        .batchWrite({ RequestItems: { [tableName]: writeRequests } })
        .promise();
};
exports.getItem = async (region, tableName, key) => {
    const db = new AWS.DynamoDB.DocumentClient({ region });
    const dbItem = await db.get({ TableName: tableName, Key: key }).promise();
    // Item is undefined if key not found
    return dbItem.Item;
};
//# sourceMappingURL=dynamoDb.js.map