"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = require("aws-sdk");
const getRecords = async (kinesis, shardIterator) => {
    const { NextShardIterator: nextShardIterator, Records: records, } = await kinesis.getRecords({ ShardIterator: shardIterator }).promise();
    const data = records.map(r => JSON.parse(r.Data.toString()));
    return { nextShardIterator, data };
};
const sleep = async (time) => {
    return await new Promise(resolve => setTimeout(resolve, time));
};
exports.existsInShard = async (kinesis, shardIterator, matcher, timeout, pollEvery) => {
    if (!shardIterator) {
        return false;
    }
    let found = false;
    let timeoutReached = false;
    const start = new Date().getTime();
    let nextShardIterator = shardIterator;
    do {
        const records = await getRecords(kinesis, nextShardIterator);
        const data = records.data;
        const index = data.findIndex(matcher);
        if (index >= 0) {
            found = true;
            break;
        }
        const currentTime = new Date().getTime();
        timeoutReached = currentTime - start >= timeout;
        if (timeoutReached) {
            break;
        }
        nextShardIterator = records.nextShardIterator || '';
        if (nextShardIterator) {
            // throttle the consumer
            await sleep(pollEvery);
        }
    } while (nextShardIterator);
    return found;
};
exports.existsInStream = async (region, stream, matcher, timeout, pollEvery = 500) => {
    const kinesis = new aws_sdk_1.Kinesis({ region });
    const streamDescription = await kinesis
        .describeStream({ StreamName: stream })
        .promise();
    const shardIterators = await Promise.all(
    // search in all shards
    streamDescription.StreamDescription.Shards.map(s => {
        return kinesis
            .getShardIterator({
            ShardId: s.ShardId,
            ShardIteratorType: 'AT_TIMESTAMP',
            StreamName: stream,
            Timestamp: new Date(Date.now() - 1000 * 60 * 5),
        })
            .promise();
    }));
    const results = await Promise.all(shardIterators.map(s => exports.existsInShard(kinesis, s.ShardIterator, matcher, timeout, pollEvery)));
    const exists = results.some(r => r);
    return exists;
};
//# sourceMappingURL=kinesis.js.map