"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const listAllKeys = async (region, bucket, prefix, token) => {
    const s3 = new AWS.S3({ region });
    const opts = Object.assign({ Bucket: bucket, ContinuationToken: token }, (prefix && { Prefix: prefix }));
    const data = await s3.listObjectsV2(opts).promise();
    let allKeys = data.Contents || [];
    if (data.IsTruncated) {
        allKeys = allKeys.concat(await listAllKeys(region, bucket, prefix, data.NextContinuationToken));
    }
    return allKeys;
};
exports.clearAllObjects = async (region, bucket, prefix) => {
    const allKeys = await listAllKeys(region, bucket, prefix, undefined);
    if (allKeys.length > 0) {
        const s3 = new AWS.S3({ region });
        const objects = allKeys.map(item => ({ Key: item.Key || '' }));
        await s3
            .deleteObjects({
            Bucket: bucket,
            Delete: {
                Objects: objects,
                Quiet: false,
            },
        })
            .promise();
    }
};
exports.getObject = async (region, bucket, key) => {
    try {
        const s3 = new AWS.S3({ region });
        // throws error if key not found
        const body = (await s3.getObject({ Bucket: bucket, Key: key }).promise())
            .Body;
        return { body, found: true };
    }
    catch (e) {
        if (e.code === 'NoSuchKey') {
            return { body: null, found: false };
        }
        else {
            throw e;
        }
    }
};
//# sourceMappingURL=s3.js.map