"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
exports.subscribeToTopic = async (region, topicArn) => {
    const sqs = new AWS.SQS({ region });
    const { QueueUrl = '' } = await sqs
        .createQueue({ QueueName: 'TestNotificationTopicQueue' })
        .promise();
    const { Attributes = {} } = await sqs
        .getQueueAttributes({
        AttributeNames: ['QueueArn'],
        QueueUrl,
    })
        .promise();
    const { QueueArn } = Attributes;
    const policy = {
        Statement: [
            {
                Action: 'sqs:SendMessage',
                Condition: {
                    ArnEquals: {
                        'aws:SourceArn': topicArn,
                    },
                },
                Effect: 'Allow',
                Principal: {
                    AWS: '*',
                },
                Resource: QueueArn,
                Sid: 'TestNotificationTopicQueuePolicy',
            },
        ],
    };
    await sqs
        .setQueueAttributes({
        Attributes: { Policy: JSON.stringify(policy) },
        QueueUrl,
    })
        .promise();
    const sns = new AWS.SNS({ region });
    const { SubscriptionArn = '' } = await sns
        .subscribe({ TopicArn: topicArn, Protocol: 'sqs', Endpoint: QueueArn })
        .promise();
    return { SubscriptionArn, QueueUrl };
};
exports.unsubscribeFromTopic = async (region, subscriptionArn, queueUrl) => {
    const sqs = new AWS.SQS({ region });
    const sns = new AWS.SNS({ region });
    await sns.unsubscribe({ SubscriptionArn: subscriptionArn }).promise();
    await sqs.deleteQueue({ QueueUrl: queueUrl }).promise();
};
//# sourceMappingURL=sns.js.map