"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const uuid_1 = require("uuid");
exports.subscribeToTopic = async (region, topicArn) => {
    const sqs = new AWS.SQS({ region });
    const queueName = `TestNotificationTopicQueue-${uuid_1.v1()}`;
    const { QueueUrl } = (await sqs
        .createQueue({
        Attributes: { VisibilityTimeout: '0' },
        QueueName: queueName,
    })
        .promise());
    const { Attributes } = (await sqs
        .getQueueAttributes({
        AttributeNames: ['QueueArn'],
        QueueUrl,
    })
        .promise());
    const { QueueArn } = Attributes;
    const policy = {
        Statement: [
            {
                Action: 'sqs:SendMessage',
                Condition: {
                    ArnEquals: {
                        'aws:SourceArn': topicArn,
                    },
                },
                Effect: 'Allow',
                Principal: {
                    AWS: '*',
                },
                Resource: QueueArn,
                Sid: 'TestNotificationTopicQueuePolicy',
            },
        ],
    };
    await sqs
        .setQueueAttributes({
        Attributes: { Policy: JSON.stringify(policy) },
        QueueUrl,
    })
        .promise();
    const sns = new AWS.SNS({ region });
    const { SubscriptionArn } = await sns
        .subscribe({ TopicArn: topicArn, Protocol: 'sqs', Endpoint: QueueArn })
        .promise();
    return { subscriptionArn: SubscriptionArn, queueUrl: QueueUrl };
};
exports.unsubscribeFromTopic = async (region, subscriptionArn, queueUrl) => {
    const sqs = new AWS.SQS({ region });
    const sns = new AWS.SNS({ region });
    await sns.unsubscribe({ SubscriptionArn: subscriptionArn }).promise();
    await sqs.deleteQueue({ QueueUrl: queueUrl }).promise();
};
exports.existsInQueue = async (region, queueUrl, matcher) => {
    const sqs = new AWS.SQS({ region });
    const { Messages = [] } = await sqs
        .receiveMessage({ QueueUrl: queueUrl, WaitTimeSeconds: 20 })
        .promise();
    const messages = Messages.map(item => JSON.parse(item.Body));
    const exists = messages.some(matcher);
    return exists;
};
//# sourceMappingURL=sqs.js.map