"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const getExecutions = async (region, stateMachineArn, statusFilter) => {
    const stepFunctions = new AWS.StepFunctions({ region });
    const opts = Object.assign({ maxResults: 1, stateMachineArn }, (statusFilter && { statusFilter }));
    const result = await stepFunctions.listExecutions(opts).promise();
    const { executions } = result;
    return executions;
};
const RUNNING = 'RUNNING';
exports.getEventName = (event) => {
    const { name } = event.stateEnteredEventDetails ||
        event.stateExitedEventDetails || {
        name: undefined,
    };
    return name;
};
exports.getCurrentState = async (region, stateMachineArn) => {
    const executions = await getExecutions(region, stateMachineArn, RUNNING);
    if (executions.length > 0) {
        const newestRunning = executions[0]; // the first is the newest one
        const stepFunctions = new AWS.StepFunctions({ region });
        const { executionArn } = newestRunning;
        const { events } = await stepFunctions
            .getExecutionHistory({ executionArn, reverseOrder: true, maxResults: 1 })
            .promise();
        if (events.length > 0) {
            const newestEvent = events[0];
            const name = exports.getEventName(newestEvent);
            return name;
        }
        else {
            return undefined;
        }
    }
    return undefined;
};
exports.getStates = async (region, stateMachineArn) => {
    const executions = await getExecutions(region, stateMachineArn);
    if (executions.length > 0) {
        const newestRunning = executions[0]; // the first is the newest one
        const stepFunctions = new AWS.StepFunctions({ region });
        const { executionArn } = newestRunning;
        const { events } = await stepFunctions
            .getExecutionHistory({ executionArn, reverseOrder: true })
            .promise();
        const names = events
            .map(event => exports.getEventName(event))
            .filter(name => !!name);
        return names;
    }
    return [];
};
exports.stopRunningExecutions = async (region, stateMachineArn) => {
    const stepFunctions = new AWS.StepFunctions({ region });
    const executions = await getExecutions(region, stateMachineArn, RUNNING);
    await Promise.all(executions.map(({ executionArn }) => stepFunctions.stopExecution({ executionArn }).promise()));
};
//# sourceMappingURL=stepFunctions.js.map